# 📈 Graphviz

Graphviz is open source graph visualization software. Graph visualization is a way of representing structural information as diagrams of abstract graphs and networks. For some of the graphs in [Reporter](../) this software is needed and it will throw an error if trying to use a feature that requires this and you do not have this installed on your machine.&#x20;

To get this software click the link below, find the version you need for your machines operating system and follow the installation process.

{% embed url="https://graphviz.org/download/" %}
